@@ -5,7 +5,7 @@ use strict;
 use utf8;
 use Carp;
 
-our $VERSION = 'v0.1.5';
+our $VERSION = 'v0.1.6';
 
 use Export::Attrs;
 use List::Util qw( any );
@@ -39,6 +39,8 @@ eval {
     _mock_ev();
 };
 eval {
+    require Mojolicious;
+    Mojolicious->VERSION('6'); # may be compatible with older ones, needs testing
     require Mojo::Reactor::Poll;
     _mock_mojolicious();
 };
@@ -492,6 +494,8 @@ __END__
 
 =encoding utf8
 
+=for stopwords localtime gmtime gettimeofday usleep nanosleep
+
 =head1 NAME
 
 Test::Mock::Time - Deterministic time & timers for event loop tests
@@ -499,7 +503,7 @@ Test::Mock::Time - Deterministic time & timers for event loop tests
 
 =head1 VERSION
 
-This document describes Test::Mock::Time version v0.1.5
+This document describes Test::Mock::Time version v0.1.6
 
 
 =head1 SYNOPSIS
@@ -556,9 +560,7 @@ These functions are exported by default:
 
 =head1 INTERFACE
 
-=over
-
-=item WAIT_ONE_TICK
+=head2 WAIT_ONE_TICK
 
     $Test::Mock::Time::WAIT_ONE_TICK = 0.05;
 
@@ -568,7 +570,7 @@ some active timers. In case no events happens while this time event loop
 will be interrupted and time will be fast-forward to time when next timer
 should expire by calling ff().
 
-=item ff
+=head2 ff
 
     ff( $seconds );
     ff();
@@ -584,8 +586,6 @@ When called without params will fast-forward time by amount needed to run
 callback for next pending timer (it may be 0 in case there are no pending
 timers or if next pending timer already expired).
 
-=back
-
 =head2 Mocked functions/methods from other modules
 
 See L</"SYNOPSIS"> for explanation how they works.
@@ -694,7 +694,7 @@ Alex Efros E<lt>powerman@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Alex Efros E<lt>powerman@cpan.orgE<gt>.
+This software is Copyright (c) 2016- by Alex Efros E<lt>powerman@cpan.orgE<gt>.
 
 This is free software, licensed under:
 
